
(setq org-roam-directory (file-truename "~/org-roam"))
(org-roam-db-autosync-mode)
(require 'ox-publish)
(require 'org-projectile)
(setq org-export-html-coding-system 'utf-8-unix)
(setq org-html-doctype "html5")
(defvar fschlde-html-head "<link type='text/css' rel='stylesheet' href='../css/plain.css'>")
(setq fschlde-html-footer " <footer>\nfschl.de 2018-2022\n</footer>")
(setq org-publish-project-alist
      '(("website"
         :components ("org-journal", "project-notes", "org-sites", "blog-rss",  "blog-images"))
        ("org-journal"
         :base-directory "~/Documents/Org/"
         :base-extension "org"
         :publishing-directory "~/projects/blog-fschlde/reads/"
         :recursive nil
         :publishing-function org-html-publish-to-html

         :headline-levels 4
         :with-author t
         :with-creator nil
         :with-date t

         :with-toc t
         :with-drawers nil

         :html-link-home "/"
         :html-head nil ;; cleans up anything that would have been in there.
         ;; :html-head-extra ,my-blog-extra-head
         :html-head-include-default-style nil
         :html-head-include-scripts nil

         ;; :html-preamble my-blog-header
         ;; :html-postamble ,my-blog-footer
         )
        ("project-notes"
         :base-directory "~/projects/"
         :base-extension "org"
         :publishing-directory "~/projects/blog-fschlde/projects/"
         :recursive nil
         :publishing-function org-html-publish-to-html
         :headline-levels 4)
        ("org-sites"
         :base-directory "~/projects/fschlde-static/"
         :base-extension "org"
         :publishing-directory "~/projects/fschlde-static/"
         :recursive t
         :publishing-function org-html-publish-to-html

         :html-link-home "/"
         ;; :html-head ,fschlde-html-head ;; cleans up anything that would have been in there.
         :html-head-include-default-style nil
         :html-head-include-scripts nil
         :with-drawers nil
         :with-creator nil

         ;; :html-head-extra fschlde-html-head
         ;; :html-postamble fschlde-html-footer
         :headline-levels 4)
        )
      )
(setq org-default-notes-file "~/Documents/Org/tasks.org")
(setq org-agenda-files
      (quote ("~/Documents/Org/tasks.org"
              "~/Documents/Org/journal.org"
              "~/Documents/Org/private.org"
              "~/Documents/Org/projects.org"
              "~/Documents/Org/birthdays.org")))

(defun fschl/create-org-letter ()
  "Create a new letter in ~/Documents/letters/ with filename and date"
  (interactive)
  (let ((name (read-string "Filename: ")))
    (expand-file-name (format "%s.org" name) "~/Documents/letters/") ))

;; https://orgmode.org/manual/Template-elements.html
;; https://orgmode.org/manual/Template-expansion.html
(setq org-capture-templates
      '(("t" "todo list item" entry
         (file+olp+datetree "~/Documents/Org/tasks.org")
         "* TODO %?\n SCHEDULED: %^T"
         :tree-type month
         )
        ("T" "todo list item with source" entry
         (file+olp+datetree "~/Documents/Org/tasks.org")
         "* TODO %?\n %a \n SCHEDULED: %^T \n %^G \n"
         :tree-type month
         )

        ("r" "Todo research some website/software" entry
         (file+olp+datetree "~/Documents/Org/tasks.org")
         "* TODO %?\n  SCHEDULED: %^T \n %^L \n"
         :tree-type month
         )
        ("l" "letter to Documents/letters/<datetime.org>"
         entry (file fschl/create-org-letter)
         "* %? \n\n * \n\n "
         )
        ("m" "Schedule a meeting" entry
         (file+headline "~/Documents/Org/tasks.org")
         "* MEETING %?\n SCHEDULED: %^T\n %a"
         )

        ("p" "Schedule a phone call" entry
         (file+headline "~/Documents/Org/tasks.org")
         "* PHONE %?\n SCHEDULED: %^T\\n %a"
         )

        ("a" "Articles: keep notes of online articles"
         entry
         (file+datetree "~/Documents/Org/journal.org")
         "* %? \n%x \n %u\n- $?"
         :tree-type month
         :kill-buffer t
         :empty-lines-before 1)
        )
      )

(setq org-ref-default-bibliography '("~/Documents/WHZ/MA/latex/references.bib")
      org-ref-pdf-directory "~/Documents/WHZ/MA/references/"
      org-ref-bibliography-notes "~/Documents/WHZ/MA/notes.org")
